
import sys
if sys.version_info >= (3, 8):
    from typing import Protocol
else:
    from typing_extensions import Protocol

import java.io
import java.lang
import java.util
import jpype
import jneqsim.neqsim.fluidMechanics.flowNode
import jneqsim.neqsim.fluidMechanics.flowSolver
import jneqsim.neqsim.fluidMechanics.flowSystem.onePhaseFlowSystem
import jneqsim.neqsim.fluidMechanics.flowSystem.twoPhaseFlowSystem
import jneqsim.neqsim.fluidMechanics.geometryDefinitions
import jneqsim.neqsim.fluidMechanics.util.fluidMechanicsVisualization.flowSystemVisualization
import jneqsim.neqsim.fluidMechanics.util.timeSeries
import jneqsim.neqsim.thermo.system
import typing



class FlowSystemInterface:
    def calcFluxes(self) -> None: ...
    def createSystem(self) -> None: ...
    def getDisplay(self) -> jneqsim.neqsim.fluidMechanics.util.fluidMechanicsVisualization.flowSystemVisualization.FlowSystemVisualizationInterface: ...
    def getFlowNodes(self) -> typing.MutableSequence[jneqsim.neqsim.fluidMechanics.flowNode.FlowNodeInterface]: ...
    def getInletPressure(self) -> float: ...
    def getInletTemperature(self) -> float: ...
    def getLegHeights(self) -> typing.MutableSequence[float]: ...
    def getNode(self, int: int) -> jneqsim.neqsim.fluidMechanics.flowNode.FlowNodeInterface: ...
    def getNumberOfLegs(self) -> int: ...
    def getNumberOfNodesInLeg(self, int: int) -> int: ...
    def getSolver(self) -> jneqsim.neqsim.fluidMechanics.flowSolver.FlowSolverInterface: ...
    def getSystemLength(self) -> float: ...
    def getTimeSeries(self) -> jneqsim.neqsim.fluidMechanics.util.timeSeries.TimeSeries: ...
    @typing.overload
    def getTotalMolarMassTransferRate(self, int: int) -> float: ...
    @typing.overload
    def getTotalMolarMassTransferRate(self, int: int, int2: int) -> float: ...
    def getTotalNumberOfNodes(self) -> int: ...
    @typing.overload
    def getTotalPressureDrop(self) -> float: ...
    @typing.overload
    def getTotalPressureDrop(self, int: int) -> float: ...
    def init(self) -> None: ...
    def print_(self) -> None: ...
    def setEndPressure(self, double: float) -> None: ...
    def setEquilibriumHeatTransfer(self, boolean: bool) -> None: ...
    def setEquilibriumMassTransfer(self, boolean: bool) -> None: ...
    def setEquipmentGeometry(self, geometryDefinitionInterfaceArray: typing.Union[typing.List[jneqsim.neqsim.fluidMechanics.geometryDefinitions.GeometryDefinitionInterface], jpype.JArray]) -> None: ...
    def setFlowPattern(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setInitialFlowPattern(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setInletThermoSystem(self, systemInterface: jneqsim.neqsim.thermo.system.SystemInterface) -> None: ...
    def setLegHeights(self, doubleArray: typing.Union[typing.List[float], jpype.JArray]) -> None: ...
    def setLegOuterHeatTransferCoefficients(self, doubleArray: typing.Union[typing.List[float], jpype.JArray]) -> None: ...
    def setLegOuterTemperatures(self, doubleArray: typing.Union[typing.List[float], jpype.JArray]) -> None: ...
    def setLegPositions(self, doubleArray: typing.Union[typing.List[float], jpype.JArray]) -> None: ...
    def setLegWallHeatTransferCoefficients(self, doubleArray: typing.Union[typing.List[float], jpype.JArray]) -> None: ...
    def setNodes(self) -> None: ...
    def setNumberOfLegs(self, int: int) -> None: ...
    def setNumberOfNodesInLeg(self, int: int) -> None: ...
    @typing.overload
    def solveSteadyState(self, int: int, uUID: java.util.UUID) -> None: ...
    @typing.overload
    def solveSteadyState(self, int: int) -> None: ...
    @typing.overload
    def solveTransient(self, int: int, uUID: java.util.UUID) -> None: ...
    @typing.overload
    def solveTransient(self, int: int) -> None: ...

class FlowSystem(FlowSystemInterface, java.io.Serializable):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, systemInterface: jneqsim.neqsim.thermo.system.SystemInterface): ...
    def calcFluxes(self) -> None: ...
    def calcTotalNumberOfNodes(self) -> int: ...
    def createSystem(self) -> None: ...
    def flowLegInit(self) -> None: ...
    def getDisplay(self) -> jneqsim.neqsim.fluidMechanics.util.fluidMechanicsVisualization.flowSystemVisualization.FlowSystemVisualizationInterface: ...
    def getFlowNodes(self) -> typing.MutableSequence[jneqsim.neqsim.fluidMechanics.flowNode.FlowNodeInterface]: ...
    def getInletPressure(self) -> float: ...
    def getInletTemperature(self) -> float: ...
    def getLegHeights(self) -> typing.MutableSequence[float]: ...
    def getNode(self, int: int) -> jneqsim.neqsim.fluidMechanics.flowNode.FlowNodeInterface: ...
    def getNumberOfLegs(self) -> int: ...
    def getNumberOfNodesInLeg(self, int: int) -> int: ...
    def getSolver(self) -> jneqsim.neqsim.fluidMechanics.flowSolver.FlowSolverInterface: ...
    def getSystemLength(self) -> float: ...
    def getTimeSeries(self) -> jneqsim.neqsim.fluidMechanics.util.timeSeries.TimeSeries: ...
    @typing.overload
    def getTotalMolarMassTransferRate(self, int: int) -> float: ...
    @typing.overload
    def getTotalMolarMassTransferRate(self, int: int, int2: int) -> float: ...
    def getTotalNumberOfNodes(self) -> int: ...
    @typing.overload
    def getTotalPressureDrop(self) -> float: ...
    @typing.overload
    def getTotalPressureDrop(self, int: int) -> float: ...
    def init(self) -> None: ...
    def print_(self) -> None: ...
    def setEndPressure(self, double: float) -> None: ...
    def setEquilibriumHeatTransfer(self, boolean: bool) -> None: ...
    def setEquilibriumHeatTransferModel(self, int: int, int2: int) -> None: ...
    def setEquilibriumMassTransfer(self, boolean: bool) -> None: ...
    def setEquilibriumMassTransferModel(self, int: int, int2: int) -> None: ...
    def setEquipmentGeometry(self, geometryDefinitionInterfaceArray: typing.Union[typing.List[jneqsim.neqsim.fluidMechanics.geometryDefinitions.GeometryDefinitionInterface], jpype.JArray]) -> None: ...
    def setFlowPattern(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setInitialFlowPattern(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setInletThermoSystem(self, systemInterface: jneqsim.neqsim.thermo.system.SystemInterface) -> None: ...
    def setLegHeights(self, doubleArray: typing.Union[typing.List[float], jpype.JArray]) -> None: ...
    def setLegOuterHeatTransferCoefficients(self, doubleArray: typing.Union[typing.List[float], jpype.JArray]) -> None: ...
    def setLegOuterTemperatures(self, doubleArray: typing.Union[typing.List[float], jpype.JArray]) -> None: ...
    def setLegPositions(self, doubleArray: typing.Union[typing.List[float], jpype.JArray]) -> None: ...
    def setLegWallHeatTransferCoefficients(self, doubleArray: typing.Union[typing.List[float], jpype.JArray]) -> None: ...
    def setNodes(self) -> None: ...
    def setNonEquilibriumHeatTransferModel(self, int: int, int2: int) -> None: ...
    def setNonEquilibriumMassTransferModel(self, int: int, int2: int) -> None: ...
    def setNumberOfLegs(self, int: int) -> None: ...
    def setNumberOfNodesInLeg(self, int: int) -> None: ...


class __module_protocol__(Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("jneqsim.neqsim.fluidMechanics.flowSystem")``.

    FlowSystem: typing.Type[FlowSystem]
    FlowSystemInterface: typing.Type[FlowSystemInterface]
    onePhaseFlowSystem: jneqsim.neqsim.fluidMechanics.flowSystem.onePhaseFlowSystem.__module_protocol__
    twoPhaseFlowSystem: jneqsim.neqsim.fluidMechanics.flowSystem.twoPhaseFlowSystem.__module_protocol__
