
import sys
if sys.version_info >= (3, 8):
    from typing import Protocol
else:
    from typing_extensions import Protocol

import java.lang
import jpype
import jneqsim.neqsim.physicalProperties.mixingRule
import jneqsim.neqsim.physicalProperties.physicalPropertyMethods.methodInterface
import jneqsim.neqsim.physicalProperties.physicalPropertySystem.commonPhasePhysicalProperties
import jneqsim.neqsim.physicalProperties.physicalPropertySystem.gasPhysicalProperties
import jneqsim.neqsim.physicalProperties.physicalPropertySystem.liquidPhysicalProperties
import jneqsim.neqsim.physicalProperties.physicalPropertySystem.solidPhysicalProperties
import jneqsim.neqsim.thermo
import jneqsim.neqsim.thermo.phase
import typing



class PhysicalPropertiesInterface(java.lang.Cloneable):
    def calcDensity(self) -> float: ...
    def calcEffectiveDiffusionCoefficients(self) -> None: ...
    def clone(self) -> 'PhysicalPropertiesInterface': ...
    def getConductivity(self) -> float: ...
    def getConductivityModel(self) -> jneqsim.neqsim.physicalProperties.physicalPropertyMethods.methodInterface.ConductivityInterface: ...
    def getDensity(self) -> float: ...
    @typing.overload
    def getDiffusionCoefficient(self, int: int, int2: int) -> float: ...
    @typing.overload
    def getDiffusionCoefficient(self, string: typing.Union[java.lang.String, str], string2: typing.Union[java.lang.String, str]) -> float: ...
    @typing.overload
    def getEffectiveDiffusionCoefficient(self, int: int) -> float: ...
    @typing.overload
    def getEffectiveDiffusionCoefficient(self, string: typing.Union[java.lang.String, str]) -> float: ...
    def getEffectiveSchmidtNumber(self, int: int) -> float: ...
    def getFickDiffusionCoefficient(self, int: int, int2: int) -> float: ...
    def getKinematicViscosity(self) -> float: ...
    def getMixingRule(self) -> jneqsim.neqsim.physicalProperties.mixingRule.PhysicalPropertyMixingRuleInterface: ...
    def getPhase(self) -> jneqsim.neqsim.thermo.phase.PhaseInterface: ...
    def getPureComponentViscosity(self, int: int) -> float: ...
    def getViscosity(self) -> float: ...
    def getViscosityModel(self) -> jneqsim.neqsim.physicalProperties.physicalPropertyMethods.methodInterface.ViscosityInterface: ...
    def getViscosityOfWaxyOil(self, double: float, double2: float) -> float: ...
    @typing.overload
    def init(self, phaseInterface: jneqsim.neqsim.thermo.phase.PhaseInterface) -> None: ...
    @typing.overload
    def init(self, phaseInterface: jneqsim.neqsim.thermo.phase.PhaseInterface, string: typing.Union[java.lang.String, str]) -> None: ...
    def setBinaryDiffusionCoefficientMethod(self, int: int) -> None: ...
    def setConductivityModel(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setDensityModel(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setMixingRule(self, physicalPropertyMixingRuleInterface: jneqsim.neqsim.physicalProperties.mixingRule.PhysicalPropertyMixingRuleInterface) -> None: ...
    def setMixingRuleNull(self) -> None: ...
    def setMulticomponentDiffusionMethod(self, int: int) -> None: ...
    def setPhase(self, phaseInterface: jneqsim.neqsim.thermo.phase.PhaseInterface) -> None: ...
    def setViscosityModel(self, string: typing.Union[java.lang.String, str]) -> None: ...

class PhysicalProperties(PhysicalPropertiesInterface, jneqsim.neqsim.thermo.ThermodynamicConstantsInterface):
    phase: jneqsim.neqsim.thermo.phase.PhaseInterface = ...
    conductivityCalc: jneqsim.neqsim.physicalProperties.physicalPropertyMethods.methodInterface.ConductivityInterface = ...
    viscosityCalc: jneqsim.neqsim.physicalProperties.physicalPropertyMethods.methodInterface.ViscosityInterface = ...
    diffusivityCalc: jneqsim.neqsim.physicalProperties.physicalPropertyMethods.methodInterface.DiffusivityInterface = ...
    densityCalc: jneqsim.neqsim.physicalProperties.physicalPropertyMethods.methodInterface.DensityInterface = ...
    kinematicViscosity: float = ...
    density: float = ...
    viscosity: float = ...
    conductivity: float = ...
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, phaseInterface: jneqsim.neqsim.thermo.phase.PhaseInterface): ...
    @typing.overload
    def __init__(self, phaseInterface: jneqsim.neqsim.thermo.phase.PhaseInterface, int: int, int2: int): ...
    def calcDensity(self) -> float: ...
    def calcEffectiveDiffusionCoefficients(self) -> None: ...
    def calcKinematicViscosity(self) -> float: ...
    def clone(self) -> 'PhysicalProperties': ...
    def getConductivity(self) -> float: ...
    def getConductivityModel(self) -> jneqsim.neqsim.physicalProperties.physicalPropertyMethods.methodInterface.ConductivityInterface: ...
    def getDensity(self) -> float: ...
    @typing.overload
    def getDiffusionCoefficient(self, int: int, int2: int) -> float: ...
    @typing.overload
    def getDiffusionCoefficient(self, string: typing.Union[java.lang.String, str], string2: typing.Union[java.lang.String, str]) -> float: ...
    @typing.overload
    def getEffectiveDiffusionCoefficient(self, int: int) -> float: ...
    @typing.overload
    def getEffectiveDiffusionCoefficient(self, string: typing.Union[java.lang.String, str]) -> float: ...
    def getEffectiveSchmidtNumber(self, int: int) -> float: ...
    def getFickDiffusionCoefficient(self, int: int, int2: int) -> float: ...
    def getKinematicViscosity(self) -> float: ...
    def getMixingRule(self) -> jneqsim.neqsim.physicalProperties.mixingRule.PhysicalPropertyMixingRuleInterface: ...
    def getPhase(self) -> jneqsim.neqsim.thermo.phase.PhaseInterface: ...
    def getPureComponentViscosity(self, int: int) -> float: ...
    def getViscosity(self) -> float: ...
    def getViscosityModel(self) -> jneqsim.neqsim.physicalProperties.physicalPropertyMethods.methodInterface.ViscosityInterface: ...
    def getViscosityOfWaxyOil(self, double: float, double2: float) -> float: ...
    def getWaxViscosityParameter(self) -> typing.MutableSequence[float]: ...
    @typing.overload
    def init(self, phaseInterface: jneqsim.neqsim.thermo.phase.PhaseInterface) -> None: ...
    @typing.overload
    def init(self, phaseInterface: jneqsim.neqsim.thermo.phase.PhaseInterface, string: typing.Union[java.lang.String, str]) -> None: ...
    def setBinaryDiffusionCoefficientMethod(self, int: int) -> None: ...
    def setConductivityModel(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setDensityModel(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setDiffusionCoefficientModel(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setMixingRule(self, physicalPropertyMixingRuleInterface: jneqsim.neqsim.physicalProperties.mixingRule.PhysicalPropertyMixingRuleInterface) -> None: ...
    def setMixingRuleNull(self) -> None: ...
    def setMulticomponentDiffusionMethod(self, int: int) -> None: ...
    def setPhase(self, phaseInterface: jneqsim.neqsim.thermo.phase.PhaseInterface) -> None: ...
    def setPhases(self) -> None: ...
    def setViscosityModel(self, string: typing.Union[java.lang.String, str]) -> None: ...
    @typing.overload
    def setWaxViscosityParameter(self, doubleArray: typing.Union[typing.List[float], jpype.JArray]) -> None: ...
    @typing.overload
    def setWaxViscosityParameter(self, int: int, double: float) -> None: ...


class __module_protocol__(Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("jneqsim.neqsim.physicalProperties.physicalPropertySystem")``.

    PhysicalProperties: typing.Type[PhysicalProperties]
    PhysicalPropertiesInterface: typing.Type[PhysicalPropertiesInterface]
    commonPhasePhysicalProperties: jneqsim.neqsim.physicalProperties.physicalPropertySystem.commonPhasePhysicalProperties.__module_protocol__
    gasPhysicalProperties: jneqsim.neqsim.physicalProperties.physicalPropertySystem.gasPhysicalProperties.__module_protocol__
    liquidPhysicalProperties: jneqsim.neqsim.physicalProperties.physicalPropertySystem.liquidPhysicalProperties.__module_protocol__
    solidPhysicalProperties: jneqsim.neqsim.physicalProperties.physicalPropertySystem.solidPhysicalProperties.__module_protocol__
